@@ -14,7 +14,7 @@
 #'   # Instantiate Resampling
 #'   rrcv = rsmp("repeated_spcv_block",
 #'     folds = 3, repeats = 2,
-#'     range = c(5000, 10000))
+#'     range = c(5000L, 10000L))
 #'   rrcv$instantiate(task)
 #'
 #'   # Individual sets:
@@ -44,10 +44,17 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
         ParamInt$new("repeats", lower = 1, default = 1L, tags = "required"),
         ParamInt$new("rows", lower = 1L),
         ParamInt$new("cols", lower = 1L),
-        ParamUty$new("range"),
+        ParamUty$new("range",
+          custom_check = function(x) checkmate::assert_integer(x)),
         ParamFct$new("selection", levels = c(
           "random", "systematic",
-          "checkerboard"), default = "random")
+          "checkerboard"), default = "random"),
+        ParamUty$new("rasterLayer",
+          default = NULL,
+          custom_check = function(x) {
+            checkmate::check_class(x, "RasterLayer",
+              null.ok = TRUE)
+          })
       ))
 
       ps$values = list(folds = 10L, repeats = 1L)
@@ -132,7 +139,11 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
       if (!is.null(groups)) {
         stopf("Grouping is not supported for spatial resampling methods.") # nocov # nolint
       }
-      instance = private$.sample(task$row_ids, task$coordinates())
+      instance = private$.sample(
+        task$row_ids,
+        task$coordinates(),
+        task$extra_args$crs
+      )
 
       self$instance = instance
       self$task_hash = task$hash
@@ -153,12 +164,14 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
   ),
 
   private = list(
-    .sample = function(ids, coords) {
+    .sample = function(ids, coords, crs) {
       pv = self$param_set$values
       folds = as.integer(pv$folds)
 
       create_blocks = function(coords, range) {
-        points = sf::st_as_sf(coords, coords = c("x", "y"))
+        points = sf::st_as_sf(coords,
+          coords = colnames(coords),
+          crs = crs)
 
         # Suppress print message, warning crs and package load
         capture.output(inds <- suppressMessages(suppressWarnings(
@@ -170,6 +183,7 @@ ResamplingRepeatedSpCVBlock = R6Class("ResamplingRepeatedSpCVBlock",
             k = self$param_set$values$folds,
             selection = self$param_set$values$selection,
             showBlocks = FALSE,
+            verbose = FALSE,
             progress = FALSE)$foldID)))
         return(inds)
       }
